@@ -226,7 +226,7 @@
     <name>ImageView</name>
     <message>
         <source>This file contains multiple pages, please use Evince to view all pages.</source>
-        <translation type="unfinished"/>
+        <translation>Ten plik zawiera wiele stron, których przejrzenie możliwe jest w programie Evince.</translation>
     </message>
 </context>
 <context>
@@ -405,6 +405,49 @@
         <translation>Model obiektywu</translation>
     </message>
 </context>
+<context>
+    <name>PrintOptionsPage</name>
+    <message>
+        <source>No scaling</source>
+        <translation>Brak skalowania</translation>
+    </message>
+    <message>
+        <source>Fit page to image</source>
+        <translation>Dopasuj stronę do obrazu</translation>
+    </message>
+    <message>
+        <source>Fit image to page</source>
+        <translation>Dopasuj obraz do strony</translation>
+    </message>
+    <message>
+        <source>Scale to:</source>
+        <translation>Zeskaluj do:</translation>
+    </message>
+    <message>
+        <source>Millimeters</source>
+        <translation>Milimetry</translation>
+    </message>
+    <message>
+        <source>Centimeters</source>
+        <translation>Centymetry</translation>
+    </message>
+    <message>
+        <source>Inches</source>
+        <translation>Cale</translation>
+    </message>
+    <message>
+        <source>Image Position</source>
+        <translation>Położenie obrazu</translation>
+    </message>
+    <message>
+        <source>Scaling</source>
+        <translation>Skalowanie</translation>
+    </message>
+    <message>
+        <source>Image Settings</source>
+        <translation>Ustawienia obrazu</translation>
+    </message>
+</context>
 <context>
     <name>QObject</name>
     <message>
@@ -728,31 +771,31 @@
     </message>
     <message>
         <source>1:1 Size</source>
-        <translation type="unfinished"/>
+        <translation>Rozmiar 1:1</translation>
     </message>
     <message>
         <source>Fit to window</source>
-        <translation type="unfinished"/>
+        <translation>Dopasuj do okna</translation>
     </message>
     <message>
         <source>Rotate counterclockwise</source>
-        <translation type="unfinished"/>
+        <translation>Obróć odwrotnie do kierunku wskazówek zegara</translation>
     </message>
     <message>
         <source>Rotate clockwise</source>
-        <translation type="unfinished"/>
+        <translation>Obróć zgodnie z kierunkiem wskazówek zegara</translation>
     </message>
     <message>
         <source>Throw to Trash</source>
-        <translation type="unfinished"/>
+        <translation>Wyrzuć do kosza</translation>
     </message>
     <message>
         <source>Unfavorite</source>
-        <translation type="unfinished"/>
+        <translation>Usuń z ulubionych</translation>
     </message>
     <message>
         <source>Favorite</source>
-        <translation type="unfinished"/>
+        <translation>Ulubione</translation>
     </message>
 </context>
 <context>
