@@ -3,7 +3,7 @@
     <name>AboutDialog</name>
     <message>
         <source>Deepin Image Viewer</source>
-        <translation type="unfinished"/>
+        <translation>Дипин Прегледач Слика</translation>
     </message>
     <message>
         <source>Version:</source>
@@ -11,22 +11,22 @@
     </message>
     <message>
         <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation type="unfinished"/>
+        <translation>Дипин Прегледач Слика је модеран &amp; префињен управник слика.</translation>
     </message>
     <message>
         <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation type="unfinished"/>
+        <translation>Својства су му управљање, прегледање и основно уређивање слика.</translation>
     </message>
 </context>
 <context>
     <name>AlbumBTContent</name>
     <message>
         <source>image</source>
-        <translation type="unfinished"/>
+        <translation>слика</translation>
     </message>
     <message>
         <source>images</source>
-        <translation type="unfinished"/>
+        <translation>слике</translation>
     </message>
     <message>
         <source>album</source>
@@ -34,22 +34,22 @@
     </message>
     <message>
         <source>albums</source>
-        <translation type="unfinished"/>
+        <translation>албуми</translation>
     </message>
     <message>
         <source>Manage sync</source>
-        <translation type="unfinished"/>
+        <translation>Управљај синхронизацијом</translation>
     </message>
     <message>
         <source>Syncing: </source>
-        <translation type="unfinished"/>
+        <translation>Синхронизација:</translation>
     </message>
 </context>
 <context>
     <name>AlbumCreateDialog</name>
     <message>
         <source>Cancel</source>
-        <translation type="unfinished"/>
+        <translation>Откажи</translation>
     </message>
     <message>
         <source>OK</source>
@@ -57,52 +57,52 @@
     </message>
     <message>
         <source>New album</source>
-        <translation type="unfinished"/>
+        <translation>Нови албум</translation>
     </message>
     <message>
         <source>Unnamed</source>
-        <translation type="unfinished"/>
+        <translation>Неименовано</translation>
     </message>
 </context>
 <context>
     <name>AlbumDelegate</name>
     <message>
         <source>Recent imported</source>
-        <translation type="unfinished"/>
+        <translation>Недавно увезено</translation>
     </message>
     <message>
         <source>My favorite</source>
-        <translation type="unfinished"/>
+        <translation>Омиљено</translation>
     </message>
 </context>
 <context>
     <name>AlbumDeleteDialog</name>
     <message>
         <source>Are your sure to delete this album?</source>
-        <translation type="unfinished"/>
+        <translation>Сигурно желите да избришете албум?</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation type="unfinished"/>
+        <translation>Откажи</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation>Обриши</translation>
+        <translation>Избриши</translation>
     </message>
 </context>
 <context>
     <name>AlbumPanel</name>
     <message>
         <source>Back</source>
-        <translation type="unfinished"/>
+        <translation>Назад</translation>
     </message>
     <message>
         <source>My favorite</source>
-        <translation type="unfinished"/>
+        <translation>Омиљено</translation>
     </message>
     <message>
         <source>Timeline</source>
-        <translation type="unfinished"/>
+        <translation>Временска линија</translation>
     </message>
     <message>
         <source>Add</source>
@@ -110,7 +110,7 @@
     </message>
     <message>
         <source>You can add sync directory or drag and drop  images to timeline</source>
-        <translation type="unfinished"/>
+        <translation>Можете додати директоријум за синхронизациу или превући слике на временску линију</translation>
     </message>
 </context>
 <context>
@@ -121,11 +121,11 @@
     </message>
     <message>
         <source>View</source>
-        <translation type="unfinished"/>
+        <translation>Прегледај</translation>
     </message>
     <message>
         <source>Slide show</source>
-        <translation type="unfinished"/>
+        <translation>Покретни приказ</translation>
     </message>
     <message>
         <source>Rename</source>
@@ -137,28 +137,28 @@
     </message>
     <message>
         <source>Delete</source>
-        <translation>Обриши</translation>
+        <translation>Избриши</translation>
     </message>
 </context>
 <context>
     <name>Application</name>
     <message>
         <source>Deepin Image Viewer</source>
-        <translation type="unfinished"/>
+        <translation>Дипин Прегледач Слика</translation>
     </message>
 </context>
 <context>
     <name>CountingThread</name>
     <message>
         <source>Images</source>
-        <translation type="unfinished"/>
+        <translation>слике</translation>
     </message>
 </context>
 <context>
     <name>DirImportDialog</name>
     <message>
         <source>Cancel</source>
-        <translation type="unfinished"/>
+        <translation>Откажи</translation>
     </message>
     <message>
         <source>OK</source>
@@ -166,34 +166,34 @@
     </message>
     <message>
         <source>Are you sure to add the pictures to the album?</source>
-        <translation type="unfinished"/>
+        <translation>Сигурно желите да додате слике у албум?</translation>
     </message>
     <message>
         <source>Sync and Create</source>
-        <translation type="unfinished"/>
+        <translation>Синхро и Направи</translation>
     </message>
     <message>
         <source>Sync</source>
-        <translation type="unfinished"/>
+        <translation>Синхро</translation>
     </message>
     <message>
         <source>Are you sure to add to the sync list and create the album named after this folder?</source>
-        <translation type="unfinished"/>
+        <translation>Желите ли да додате на листу синхронизације и направите албум именован по датотеци?</translation>
     </message>
 </context>
 <context>
     <name>Exporter</name>
     <message>
         <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
-        <translation type="unfinished"/>
+        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
     </message>
     <message>
         <source>Exported successfully</source>
-        <translation type="unfinished"/>
+        <translation>Успешно извезено</translation>
     </message>
     <message>
         <source>Failed to export</source>
-        <translation type="unfinished"/>
+        <translation>Извоз неуспешан</translation>
     </message>
     <message>
         <source>Save</source>
@@ -204,48 +204,48 @@
     <name>FileDeleteDialog</name>
     <message>
         <source>Are you sure to throw pictures to TRASH?</source>
-        <translation type="unfinished"/>
+        <translation>Сигурно желите да баците слике у СМЕЋЕ?</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation type="unfinished"/>
+        <translation>Откажи</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation>Обриши</translation>
+        <translation>Избриши</translation>
     </message>
 </context>
 <context>
     <name>ImageInfoWidget</name>
     <message>
         <source>Image info</source>
-        <translation type="unfinished"/>
+        <translation>Својства слике</translation>
     </message>
 </context>
 <context>
     <name>ImageView</name>
     <message>
         <source>This file contains multiple pages, please use Evince to view all pages.</source>
-        <translation type="unfinished"/>
+        <translation>Датотека садржи више страница, молимо користите Evince да прегледате све странице.</translation>
     </message>
 </context>
 <context>
     <name>ImagesView</name>
     <message>
         <source>View</source>
-        <translation type="unfinished"/>
+        <translation>Прегледај</translation>
     </message>
     <message>
         <source>Fullscreen</source>
-        <translation type="unfinished"/>
+        <translation>Цео екран</translation>
     </message>
     <message>
         <source>Slide show</source>
-        <translation type="unfinished"/>
+        <translation>Покретни приказ</translation>
     </message>
     <message>
         <source>Print</source>
-        <translation type="unfinished"/>
+        <translation>Штампај</translation>
     </message>
     <message>
         <source>Copy</source>
@@ -253,73 +253,73 @@
     </message>
     <message>
         <source>Copy to clipboard</source>
-        <translation type="unfinished"/>
+        <translation>Копирај у бележницу</translation>
     </message>
     <message>
         <source>Throw to trash</source>
-        <translation type="unfinished"/>
+        <translation>Баци у смеће</translation>
     </message>
     <message>
         <source>Remove from album</source>
-        <translation type="unfinished"/>
+        <translation>Уклони из албума</translation>
     </message>
     <message>
         <source>Favorite</source>
-        <translation type="unfinished"/>
+        <translation>У омиљено</translation>
     </message>
     <message>
         <source>Unfavorite</source>
-        <translation type="unfinished"/>
+        <translation>Из омиљеног</translation>
     </message>
     <message>
         <source>Rotate clockwise</source>
-        <translation type="unfinished"/>
+        <translation>Ротирај удесно</translation>
     </message>
     <message>
         <source>Rotate counterclockwise</source>
-        <translation type="unfinished"/>
+        <translation>Ротирај улево</translation>
     </message>
     <message>
         <source>Set as wallpaper</source>
-        <translation type="unfinished"/>
+        <translation>Постави као позадину</translation>
     </message>
     <message>
         <source>Display in file manager</source>
-        <translation type="unfinished"/>
+        <translation>Прикажи у управнику података</translation>
     </message>
     <message>
         <source>Image info</source>
-        <translation type="unfinished"/>
+        <translation>Својства слике</translation>
     </message>
     <message>
         <source>Add</source>
-        <translation type="unfinished"/>
+        <translation>Додај</translation>
     </message>
     <message>
         <source>You can add sync directory or drag and drop  images to timeline</source>
-        <translation type="unfinished"/>
+        <translation>Можете додати директоријум за синхронизациу или превући слике на временску линију</translation>
     </message>
     <message>
         <source>Add to album</source>
-        <translation type="unfinished"/>
+        <translation>Додај у албум</translation>
     </message>
     <message>
         <source>Add to new album</source>
-        <translation type="unfinished"/>
+        <translation>Додај у нови албум</translation>
     </message>
 </context>
 <context>
     <name>Importer</name>
     <message>
         <source>Open Directory</source>
-        <translation type="unfinished"/>
+        <translation>Отвори Директоријум</translation>
     </message>
 </context>
 <context>
     <name>LockWidget</name>
     <message>
         <source>You have no permission to view the image</source>
-        <translation type="unfinished"/>
+        <translation>Немате овлашћење да прегледате слику</translation>
     </message>
 </context>
 <context>
@@ -330,155 +330,198 @@
     </message>
     <message>
         <source>Type</source>
-        <translation type="unfinished"/>
+        <translation>Тип</translation>
     </message>
     <message>
         <source>Date photoed</source>
-        <translation type="unfinished"/>
+        <translation>Датум сликања</translation>
     </message>
     <message>
         <source>Date modified</source>
-        <translation type="unfinished"/>
+        <translation>Измењено</translation>
     </message>
     <message>
         <source>Resolution</source>
-        <translation type="unfinished"/>
+        <translation>Резолуција</translation>
     </message>
     <message>
         <source>File size</source>
-        <translation type="unfinished"/>
+        <translation>Величина</translation>
     </message>
     <message>
         <source>Colorspace</source>
-        <translation type="unfinished"/>
+        <translation>Опсег боја</translation>
     </message>
     <message>
         <source>Exposure mode</source>
-        <translation type="unfinished"/>
+        <translation>Режим експозиције</translation>
     </message>
     <message>
         <source>Exposure program</source>
-        <translation type="unfinished"/>
+        <translation>Програм експозиције</translation>
     </message>
     <message>
         <source>Exposure time</source>
-        <translation type="unfinished"/>
+        <translation>Трајање експозиције</translation>
     </message>
     <message>
         <source>Flash</source>
-        <translation type="unfinished"/>
+        <translation>Блиц</translation>
     </message>
     <message>
         <source>Aperture</source>
-        <translation type="unfinished"/>
+        <translation>Бленда</translation>
     </message>
     <message>
         <source>Focal length</source>
-        <translation type="unfinished"/>
+        <translation>Жижна даљина</translation>
     </message>
     <message>
         <source>ISO</source>
-        <translation type="unfinished"/>
+        <translation>ИСО</translation>
     </message>
     <message>
         <source>Max aperture</source>
-        <translation type="unfinished"/>
+        <translation>Највећа бленда</translation>
     </message>
     <message>
         <source>Metering mode</source>
-        <translation type="unfinished"/>
+        <translation>Режим мерача</translation>
     </message>
     <message>
         <source>White balance</source>
-        <translation type="unfinished"/>
+        <translation>Баланс беле</translation>
     </message>
     <message>
         <source>Flash compensation</source>
-        <translation type="unfinished"/>
+        <translation>Компензација блица</translation>
     </message>
     <message>
         <source>Camera model</source>
-        <translation type="unfinished"/>
+        <translation>Модел апарата</translation>
     </message>
     <message>
         <source>Lens model</source>
-        <translation type="unfinished"/>
+        <translation>Модел сочива</translation>
+    </message>
+</context>
+<context>
+    <name>PrintOptionsPage</name>
+    <message>
+        <source>No scaling</source>
+        <translation>Без скалирања</translation>
+    </message>
+    <message>
+        <source>Fit page to image</source>
+        <translation>Прилагоди страницу слици</translation>
+    </message>
+    <message>
+        <source>Fit image to page</source>
+        <translation>Прилагоди слику страници</translation>
+    </message>
+    <message>
+        <source>Scale to:</source>
+        <translation>Скалирај у:</translation>
+    </message>
+    <message>
+        <source>Millimeters</source>
+        <translation>Милиметри</translation>
+    </message>
+    <message>
+        <source>Centimeters</source>
+        <translation>Сантиметри</translation>
+    </message>
+    <message>
+        <source>Inches</source>
+        <translation>Инчи</translation>
+    </message>
+    <message>
+        <source>Image Position</source>
+        <translation>Позиција Слике</translation>
+    </message>
+    <message>
+        <source>Scaling</source>
+        <translation>Скалирање</translation>
+    </message>
+    <message>
+        <source>Image Settings</source>
+        <translation>Поставке Слике</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
         <source>Blinds</source>
-        <translation type="unfinished"/>
+        <translation>Ролетне</translation>
     </message>
     <message>
         <source>Switcher</source>
-        <translation type="unfinished"/>
+        <translation>Клапна</translation>
     </message>
     <message>
         <source>Sliding</source>
-        <translation type="unfinished"/>
+        <translation>Клизање</translation>
     </message>
     <message>
         <source>Ring</source>
-        <translation type="unfinished"/>
+        <translation>Прстен</translation>
     </message>
 </context>
 <context>
     <name>ScanPathsDialog</name>
     <message>
         <source>Select Directory</source>
-        <translation type="unfinished"/>
+        <translation>Одабери Директоријум</translation>
     </message>
     <message>
         <source>This directory is disabled to sync</source>
-        <translation type="unfinished"/>
+        <translation>Синхронизација онемогућена за овај директоријум</translation>
     </message>
     <message>
         <source>Add folder</source>
-        <translation type="unfinished"/>
+        <translation>Додај датотеку</translation>
     </message>
     <message>
         <source>Sync Directory Management</source>
-        <translation type="unfinished"/>
+        <translation>Управљање Синхронизацијом Директоријума</translation>
     </message>
     <message>
         <source>The directory list is empty</source>
-        <translation type="unfinished"/>
+        <translation>Лста диркторијума је празна</translation>
     </message>
 </context>
 <context>
     <name>ScanPathsItem</name>
     <message>
         <source>Cancel sync</source>
-        <translation type="unfinished"/>
+        <translation>Откажи синхро</translation>
     </message>
     <message>
         <source>Images</source>
-        <translation type="unfinished"/>
+        <translation>Слике</translation>
     </message>
     <message>
         <source>The device has been removed</source>
-        <translation type="unfinished"/>
+        <translation>Уређај је уклоњен</translation>
     </message>
     <message>
         <source>This directory no longer exists</source>
-        <translation type="unfinished"/>
+        <translation>Овај директоријум више не постоји</translation>
     </message>
     <message>
         <source>Calculating...</source>
-        <translation type="unfinished"/>
+        <translation>Рачунање...</translation>
     </message>
 </context>
 <context>
     <name>Shortcut</name>
     <message>
         <source>Image Viewing</source>
-        <translation type="unfinished"/>
+        <translation>Преглед Слика</translation>
     </message>
     <message>
         <source>Album</source>
-        <translation type="unfinished"/>
+        <translation>Албум</translation>
     </message>
     <message>
         <source>Settings</source>
@@ -486,140 +529,140 @@
     </message>
     <message>
         <source>View</source>
-        <translation type="unfinished"/>
+        <translation>Прегледај</translation>
     </message>
     <message>
         <source>Fullscreen</source>
-        <translation type="unfinished"/>
+        <translation>Цео екран</translation>
     </message>
     <message>
         <source>Slide show</source>
-        <translation type="unfinished"/>
+        <translation>Покретни приказ</translation>
     </message>
     <message>
         <source>End show</source>
-        <translation type="unfinished"/>
+        <translation>Окончај</translation>
     </message>
     <message>
         <source>Copy</source>
-        <translation type="unfinished"/>
+        <translation>Копирај</translation>
     </message>
     <message>
         <source>Throw to trash</source>
-        <translation type="unfinished"/>
+        <translation>Баци у смеће</translation>
     </message>
     <message>
         <source>Remove from album</source>
-        <translation type="unfinished"/>
+        <translation>Уклони из албума</translation>
     </message>
     <message>
         <source>Favorite</source>
-        <translation type="unfinished"/>
+        <translation>У омиљено</translation>
     </message>
     <message>
         <source>Unfavorite</source>
-        <translation type="unfinished"/>
+        <translation>Из омиљеног</translation>
     </message>
     <message>
         <source>Rotate clockwise</source>
-        <translation type="unfinished"/>
+        <translation>Ротирај удесно</translation>
     </message>
     <message>
         <source>Rotate counterclockwise</source>
-        <translation type="unfinished"/>
+        <translation>Ротирај улево</translation>
     </message>
     <message>
         <source>Set as wallpaper</source>
-        <translation type="unfinished"/>
+        <translation>Постави као позадину</translation>
     </message>
     <message>
         <source>Display in file manager</source>
-        <translation type="unfinished"/>
+        <translation>Прикажи у управнику података</translation>
     </message>
     <message>
         <source>Image info</source>
-        <translation type="unfinished"/>
+        <translation>Својства слике</translation>
     </message>
     <message>
         <source>Previous</source>
-        <translation type="unfinished"/>
+        <translation>Претходно</translation>
     </message>
     <message>
         <source>Next</source>
-        <translation type="unfinished"/>
+        <translation>Следеће</translation>
     </message>
     <message>
         <source>Previous screen</source>
-        <translation type="unfinished"/>
+        <translation>Претходни екран</translation>
     </message>
     <message>
         <source>Next screen</source>
-        <translation type="unfinished"/>
+        <translation>Следећи екран</translation>
     </message>
     <message>
         <source>New album</source>
-        <translation type="unfinished"/>
+        <translation>Нови албум</translation>
     </message>
     <message>
         <source>Rename</source>
-        <translation type="unfinished"/>
+        <translation>Преименуј</translation>
     </message>
     <message>
         <source>Help</source>
-        <translation type="unfinished"/>
+        <translation>Помоћ</translation>
     </message>
     <message>
         <source>Exit</source>
-        <translation type="unfinished"/>
+        <translation>Изађи</translation>
     </message>
     <message>
         <source>Display shortcuts</source>
-        <translation type="unfinished"/>
+        <translation>Прикажи пречице</translation>
     </message>
 </context>
 <context>
     <name>ShortcutEditor</name>
     <message>
         <source>Please enter a new shortcut</source>
-        <translation type="unfinished"/>
+        <translation>Молимо унесите нову пречицу</translation>
     </message>
 </context>
 <context>
     <name>ShortcutFrame</name>
     <message>
         <source>Shortcuts</source>
-        <translation type="unfinished"/>
+        <translation>Пречице</translation>
     </message>
     <message>
         <source>View Picture</source>
-        <translation type="unfinished"/>
+        <translation>Преглед Слике</translation>
     </message>
     <message>
         <source>Album</source>
-        <translation type="unfinished"/>
+        <translation>Албум</translation>
     </message>
     <message>
         <source>Restore Defaults</source>
-        <translation type="unfinished"/>
+        <translation>Врати Подрзумевано</translation>
     </message>
 </context>
 <context>
     <name>ShortcutKey</name>
     <message>
         <source>View</source>
-        <translation type="unfinished"/>
+        <translation>Прегледај</translation>
     </message>
     <message>
         <source>Fullscreen</source>
-        <translation type="unfinished"/>
+        <translation>Цео екран</translation>
     </message>
     <message>
         <source>Slide show</source>
-        <translation type="unfinished"/>
+        <translation>Покретни приказ</translation>
     </message>
     <message>
         <source>End show</source>
-        <translation type="unfinished"/>
+        <translation>Окончај</translation>
     </message>
     <message>
         <source>Print</source>
@@ -627,385 +670,385 @@
     </message>
     <message>
         <source>Copy</source>
-        <translation type="unfinished"/>
+        <translation>Копирај</translation>
     </message>
     <message>
         <source>Throw to trash</source>
-        <translation type="unfinished"/>
+        <translation>Баци у смеће</translation>
     </message>
     <message>
         <source>Remove from album</source>
-        <translation type="unfinished"/>
+        <translation>Уклони из албума</translation>
     </message>
     <message>
         <source>Favorite</source>
-        <translation type="unfinished"/>
+        <translation>У омиљено</translation>
     </message>
     <message>
         <source>Unfavorite</source>
-        <translation type="unfinished"/>
+        <translation>Из омиљеног</translation>
     </message>
     <message>
         <source>Rotate clockwise</source>
-        <translation type="unfinished"/>
+        <translation>Ротирај удесно</translation>
     </message>
     <message>
         <source>Rotate counterclockwise</source>
-        <translation type="unfinished"/>
+        <translation>Ротирај улево</translation>
     </message>
     <message>
         <source>Set as wallpaper</source>
-        <translation type="unfinished"/>
+        <translation>Постави као позадину</translation>
     </message>
     <message>
         <source>Display in file manager</source>
-        <translation type="unfinished"/>
+        <translation>Прикажи у управнику података</translation>
     </message>
     <message>
         <source>Image info</source>
-        <translation type="unfinished"/>
+        <translation>Својства слике</translation>
     </message>
     <message>
         <source>New album</source>
-        <translation type="unfinished"/>
+        <translation>Нови албум</translation>
     </message>
     <message>
         <source>Rename</source>
-        <translation type="unfinished"/>
+        <translation>Преименуј</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation type="unfinished"/>
+        <translation>Избриши</translation>
     </message>
 </context>
 <context>
     <name>SlideShowPanel</name>
     <message>
         <source>End show</source>
-        <translation type="unfinished"/>
+        <translation>Окончај</translation>
     </message>
     <message>
         <source>Pause/Play</source>
-        <translation type="unfinished"/>
+        <translation>Пауза/Пусти</translation>
     </message>
 </context>
 <context>
     <name>SlideshowFrame</name>
     <message>
         <source>Slide Settings</source>
-        <translation type="unfinished"/>
+        <translation>Поставке Покретног Приказа</translation>
     </message>
     <message>
         <source>Switch effect</source>
-        <translation type="unfinished"/>
+        <translation>Прелазни ефекти</translation>
     </message>
     <message>
         <source>Duration</source>
-        <translation type="unfinished"/>
+        <translation>Трајање</translation>
     </message>
     <message>
         <source>Switch duration</source>
-        <translation type="unfinished"/>
+        <translation>Трајање приказа</translation>
     </message>
     <message>
         <source>second</source>
-        <translation type="unfinished"/>
+        <translation>секунде</translation>
     </message>
 </context>
 <context>
     <name>TTLContent</name>
     <message>
         <source>Back</source>
-        <translation type="unfinished"/>
+        <translation>Назад</translation>
     </message>
     <message>
         <source>Image management</source>
-        <translation type="unfinished"/>
+        <translation>Управљање сликама</translation>
     </message>
     <message>
         <source>My favorite</source>
-        <translation type="unfinished"/>
+        <translation>Омиљено</translation>
     </message>
     <message>
         <source>1:1 Size</source>
-        <translation type="unfinished"/>
+        <translation>1:1 Размера</translation>
     </message>
     <message>
         <source>Fit to window</source>
-        <translation type="unfinished"/>
+        <translation>Уклопи у прозор</translation>
     </message>
     <message>
         <source>Rotate counterclockwise</source>
-        <translation type="unfinished"/>
+        <translation>Ротирај улево</translation>
     </message>
     <message>
         <source>Rotate clockwise</source>
-        <translation type="unfinished"/>
+        <translation>Ротирај удесно</translation>
     </message>
     <message>
         <source>Throw to Trash</source>
-        <translation type="unfinished"/>
+        <translation>Баци у Смеће</translation>
     </message>
     <message>
         <source>Unfavorite</source>
-        <translation type="unfinished"/>
+        <translation>Из омиљеног</translation>
     </message>
     <message>
         <source>Favorite</source>
-        <translation type="unfinished"/>
+        <translation>У омиљено</translation>
     </message>
 </context>
 <context>
     <name>ThumbnailWidget</name>
     <message>
         <source>No image files found</source>
-        <translation type="unfinished"/>
+        <translation>Нису пронађене датотеке са сликама</translation>
     </message>
 </context>
 <context>
     <name>TimelineBTContent</name>
     <message>
         <source>%1 image</source>
-        <translation type="unfinished"/>
+        <translation>%1 слика</translation>
     </message>
     <message>
         <source>%1 images</source>
-        <translation type="unfinished"/>
+        <translation>%1 слике</translation>
     </message>
     <message>
         <source>Manage sync</source>
-        <translation type="unfinished"/>
+        <translation>Управљај синхронизацијом</translation>
     </message>
     <message>
         <source>Syncing: </source>
-        <translation type="unfinished"/>
+        <translation>Синхронизација:</translation>
     </message>
 </context>
 <context>
     <name>TimelinePanel</name>
     <message>
         <source>Album</source>
-        <translation type="unfinished"/>
+        <translation>Албум</translation>
     </message>
     <message>
         <source>Add</source>
-        <translation type="unfinished"/>
+        <translation>Додај</translation>
     </message>
     <message>
         <source>You can add sync directory or drag and drop  images to timeline</source>
-        <translation type="unfinished"/>
+        <translation>Можете додати директоријум за синхронизациу или превући слике на временску линију</translation>
     </message>
     <message>
         <source>Add to album</source>
-        <translation type="unfinished"/>
+        <translation>Додај у албум</translation>
     </message>
     <message>
         <source>Add to new album</source>
-        <translation type="unfinished"/>
+        <translation>Додај у нови албум</translation>
     </message>
     <message>
         <source>View</source>
-        <translation type="unfinished"/>
+        <translation>Прегледај</translation>
     </message>
     <message>
         <source>Fullscreen</source>
-        <translation type="unfinished"/>
+        <translation>Цео екран</translation>
     </message>
     <message>
         <source>Slide show</source>
-        <translation type="unfinished"/>
+        <translation>Покретни приказ</translation>
     </message>
     <message>
         <source>Print</source>
-        <translation type="unfinished"/>
+        <translation>Штампај</translation>
     </message>
     <message>
         <source>Copy</source>
-        <translation type="unfinished"/>
+        <translation>Копирај</translation>
     </message>
     <message>
         <source>Copy to clipboard</source>
-        <translation type="unfinished"/>
+        <translation>Копирај у бележницу</translation>
     </message>
     <message>
         <source>Throw to trash</source>
-        <translation type="unfinished"/>
+        <translation>Баци у смеће</translation>
     </message>
     <message>
         <source>Favorite</source>
-        <translation type="unfinished"/>
+        <translation>У омиљено</translation>
     </message>
     <message>
         <source>Unfavorite</source>
-        <translation type="unfinished"/>
+        <translation>Из омиљеног</translation>
     </message>
     <message>
         <source>Rotate clockwise</source>
-        <translation type="unfinished"/>
+        <translation>Ротирај удесно</translation>
     </message>
     <message>
         <source>Rotate counterclockwise</source>
-        <translation type="unfinished"/>
+        <translation>Ротирај улево</translation>
     </message>
     <message>
         <source>Set as wallpaper</source>
-        <translation type="unfinished"/>
+        <translation>Постави као позадину</translation>
     </message>
     <message>
         <source>Display in file manager</source>
-        <translation type="unfinished"/>
+        <translation>Прикажи у управнику података</translation>
     </message>
     <message>
         <source>Image info</source>
-        <translation type="unfinished"/>
+        <translation>Својства слике</translation>
     </message>
 </context>
 <context>
     <name>TitleFrame</name>
     <message>
         <source>Slide Settings</source>
-        <translation type="unfinished"/>
+        <translation>Покретни Приказ</translation>
     </message>
     <message>
         <source>Effect</source>
-        <translation type="unfinished"/>
+        <translation>Ефекат</translation>
     </message>
     <message>
         <source>Duration</source>
-        <translation type="unfinished"/>
+        <translation>Трајање</translation>
     </message>
     <message>
         <source>Shortcuts</source>
-        <translation type="unfinished"/>
+        <translation>Пречице</translation>
     </message>
     <message>
         <source>View</source>
-        <translation type="unfinished"/>
+        <translation>Прегледај</translation>
     </message>
     <message>
         <source>Album</source>
-        <translation type="unfinished"/>
+        <translation>Албум</translation>
     </message>
 </context>
 <context>
     <name>TopAlbumTips</name>
     <message>
         <source>dd MMMM yyyy</source>
-        <translation type="unfinished"/>
+        <translation>dd MMMM yyyy</translation>
     </message>
     <message>
         <source>My favorite</source>
-        <translation type="unfinished"/>
+        <translation>Омиљено</translation>
     </message>
     <message>
         <source>Recent imported</source>
-        <translation type="unfinished"/>
+        <translation>Недавно увезено</translation>
     </message>
 </context>
 <context>
     <name>TopToolbar</name>
     <message>
         <source>New album</source>
-        <translation type="unfinished"/>
+        <translation>Нови албум</translation>
     </message>
     <message>
         <source>Settings</source>
-        <translation type="unfinished"/>
+        <translation>Подешавања</translation>
     </message>
     <message>
         <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
-        <translation type="unfinished"/>
+        <translation>Дипин Прегледач Слика је модеран &amp; префињен управник слика.</translation>
     </message>
     <message>
         <source>It is featured with image management, image viewing and basic image editing.</source>
-        <translation type="unfinished"/>
+        <translation>Својства су му управљање, прегледање и основно уређивање слика.</translation>
     </message>
     <message>
         <source>Dark theme</source>
-        <translation type="unfinished"/>
+        <translation>Тамна тема</translation>
     </message>
 </context>
 <context>
     <name>ViewPanel</name>
     <message>
         <source>Timeline</source>
-        <translation type="unfinished"/>
+        <translation>Временска линија</translation>
     </message>
     <message>
         <source>Add to album</source>
-        <translation type="unfinished"/>
+        <translation>Додај у албум</translation>
     </message>
     <message>
         <source>Add to new album</source>
-        <translation type="unfinished"/>
+        <translation>Додај у нови албум</translation>
     </message>
     <message>
         <source>Exit fullscreen</source>
-        <translation type="unfinished"/>
+        <translation>Напусти цео екран</translation>
     </message>
     <message>
         <source>Fullscreen</source>
-        <translation type="unfinished"/>
+        <translation>Цео екран</translation>
     </message>
     <message>
         <source>Slide show</source>
-        <translation type="unfinished"/>
+        <translation>Покретни приказ</translation>
     </message>
     <message>
         <source>Print</source>
-        <translation type="unfinished"/>
+        <translation>Штампај</translation>
     </message>
     <message>
         <source>Copy</source>
-        <translation type="unfinished"/>
+        <translation>Копирај</translation>
     </message>
     <message>
         <source>Copy to clipboard</source>
-        <translation type="unfinished"/>
+        <translation>Копирај у бележницу</translation>
     </message>
     <message>
         <source>Throw to trash</source>
-        <translation type="unfinished"/>
+        <translation>Баци у смеће</translation>
     </message>
     <message>
         <source>Remove from album</source>
-        <translation type="unfinished"/>
+        <translation>Уклони из албума</translation>
     </message>
     <message>
         <source>Favorite</source>
-        <translation type="unfinished"/>
+        <translation>У омиљено</translation>
     </message>
     <message>
         <source>Unfavorite</source>
-        <translation type="unfinished"/>
+        <translation>Из омиљеног</translation>
     </message>
     <message>
         <source>Show navigation window</source>
-        <translation type="unfinished"/>
+        <translation>Прикажи навигациони прозор</translation>
     </message>
     <message>
         <source>Hide navigation window</source>
-        <translation type="unfinished"/>
+        <translation>Сакриј навигациони прозор</translation>
     </message>
     <message>
         <source>Rotate clockwise</source>
-        <translation type="unfinished"/>
+        <translation>Ротирај удесно</translation>
     </message>
     <message>
         <source>Rotate counterclockwise</source>
-        <translation type="unfinished"/>
+        <translation>Ротирај улево</translation>
     </message>
     <message>
         <source>Set as wallpaper</source>
-        <translation type="unfinished"/>
+        <translation>Постави као позадину</translation>
     </message>
     <message>
         <source>Display in file manager</source>
-        <translation type="unfinished"/>
+        <translation>Прикажи у управнику података</translation>
     </message>
     <message>
         <source>Image info</source>
-        <translation type="unfinished"/>
+        <translation>Својства слике</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
